use std::collections::HashMap;

pub enum KeyEvent {
    Pressed(u32),
    Released(u32),
}

pub struct DeviceManager {
    key_map: HashMap<u32, bool>,
    key_event: Option<KeyEvent>,
}

impl DeviceManager {
    pub fn new() -> Self {
	DeviceManager {
	    key_map: HashMap::new(),
	    key_event: None
	}
    }
    pub fn update_key_event(&mut self, scancode: u32, pressed: bool) {
	let old = *self.key_map.get(&scancode).unwrap_or(&false);
	if old != pressed {
	    self.key_map.insert(scancode, pressed);
	    if pressed {
		self.key_event = Some(KeyEvent::Pressed(scancode));
	    } else {
		self.key_event = Some(KeyEvent::Released(scancode));
	    }
	}
    }
    pub fn handle_key_event(&mut self) -> Option<KeyEvent> {
	std::mem::replace(&mut self.key_event, None)
    }
}
